function [t,v] = cstormplot( fname, n )
%CSTORMPLOT: Plots sequence of n storms generated by CHILD.
%    Usage: [t,v] = cvolplot( fname, n )
%      fname = file name (including path)
%      n (opt) = number of lines in <fname>.storm and <fname>.vols files
%    Returns:
%      t = time vector (x-axis)
%      v = volume vector (y-axis)
%   GT, May 2010

stormfile = [fname '.storm'];
volumefile = [fname '.vols'];
sfid = fopen( stormfile, 'r' );
vfid = fopen( volumefile, 'r' );
if sfid <= 0, error(['Unable to open ' stormfile]);end
if vfid <= 0, error(['Unable to open ' volumefile]);end

% If user gives zero or negative for n, figure it out from file
if nargin<2 || n<=0
   mycomputer = computer;
   if strncmp(mycomputer,'PCWIN',5)
       error('Cannot automatically determine file length on a windows machine.');
   end
   [s,w]=unix(['wc -l ' fname '.vols']);
   n = str2num( w(1:9) );
end

hoursperyear = 24*365.25;
myr2mmhr = 1000/hoursperyear;
s = fscanf( sfid, '%f', [3,n]);
s(1,:) = s(1,:) * hoursperyear;
s(3,:) = s(3,:) * hoursperyear;

t = cumsum( (s(1,:) + s(3,:) ) );   % Row 1 = interstorm dur, row 3 = storm dur
fclose( sfid );
t = circshift(t,[0 1]);
t(1)=0;

clf

for i=1:n
    plot([t(i) t(i) t(i)+s(3,i) t(i)+s(3,i)],[0 s(2,i) s(2,i) 0])
    hold on
end
hold off
set(gca,'fontsize',14)
xlabel('Time (hours)')
ylabel('Rainfall intensity (mm/hr)')
axis([ 0 max(t) 0 1.2*max(s(2,:)) ])

